#   DrCr: Web-based double-entry bookkeeping framework
#   Copyright (C) 2022  Lee Yingtong Li (RunasSudo)
#
#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU Affero General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU Affero General Public License for more details.
#
#   You should have received a copy of the GNU Affero General Public License
#   along with this program.  If not, see <https://www.gnu.org/licenses/>.

from flask import render_template

from ..config import COA_MAPPING
from ..models import Amount, TrialBalancer
from ..webapp import all_transactions, app

@app.route('/reports/balance-sheet')
def balance_sheet():
	# Extract trial balance
	balancer = TrialBalancer()
	balancer.apply_transactions(all_transactions())
	
	# Classify accounts
	for source_account, destination_account in COA_MAPPING.items():
		balancer.transfer_balance(source_account, destination_account)
	
	balancer.transfer_balance('Income', 'Equity')
	balancer.transfer_balance('Expenses', 'Equity')
	
	total_dr = Amount(sum(v.quantity for v in balancer.accounts.values() if v.quantity > 0), '$')
	total_cr = Amount(sum(v.quantity for v in balancer.accounts.values() if v.quantity < 0), '$')
	
	return render_template('trial_balance.html', accounts=dict(sorted(balancer.accounts.items())), total_dr=total_dr, total_cr=total_cr)
